/* -----------------------------------------------------------------------------
 *    ___   __    __       _      __              __   __
 *   / _ | / /__ / /____ _| | /| / /__  ___  ____/ /  / /____ ____
 *  / __ |/  '_//  '_/ // / |/ |/ / _ `/ -_)/ __/ _ \/ __/ -_) __/
 * /_/ |_/_/\_\/_/\_\\_,_/|__/|__/\_,_/\__/ \__/_//_/\__/\__/_/
 *
 * 080824-1 (c)2009 Elektor International Media B.V.
 * -------------------------------------------------------------------------- */

#ifndef __TOOLS_H__
#define __TOOLS_H__

/* -----------------------------------------------------------------------------
 * Global Defines
 * -------------------------------------------------------------------------- */
// possible line termination
enum EOL_TYPE {
	EOL_NONE            = 0x00,
	EOL_LINE_FEED       = 0x01,
	EOL_CARRIAGE_RETURN = 0x02,

	EOL_LAST
};
// description of ASCII characters
enum ASCII_TABLE {
	ASCII_LF = 0x0A, // 10
	ASCII_CR = 0x0D, // 13

	END_OF_ASCII_TABLE
};
// status of the Error LED
enum LED_ERROR_STATUS {
	LED_OFF = 0,
	LED_ON  = 1,

	END_OF_ERROR_LED_STATUS
};


/* -----------------------------------------------------------------------------
 * Global Typedef
 * -------------------------------------------------------------------------- */
// delay in us
typedef unsigned long delay_us_t;



/* -----------------------------------------------------------------------------
 * Global Functions
 * -------------------------------------------------------------------------- */
// MCP3550 functions
extern void MCP3550_initilize(void);
extern unsigned long MCP3550_get_value(void);

// Blocking delay functions
extern void delay_initialize(void);
extern void delay_us(delay_us_t delay);

// Serial Interface functions
extern void UART_initialize(unsigned int baudrate);
extern void UART0_SendByte(unsigned char byte);
extern void UART0_SendText(char string[], char end_of_line);
extern void UART0_SendInt4(signed short value);
extern void UART0_SendInt5(unsigned short data);
extern void UART0_SendInt5_signed (signed short value);

// Internal ADC functions
extern unsigned short ADC_get_AD0_value(void);

// LCD Backlight control
extern void LCD_backlight_init(void);
extern void LCD_backlight_set_cycle(char duty_cycle);

// Error LED control
extern void LED_error_initialize(void);
extern void LED_error_set_status(char status);


#endif // __TOOLS_H__
